<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Mënyra aeroplan e aktivizuar</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Mënyra aeroplan e çaktivizuar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Çaktivizoje</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mënyra Aeroplan</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Rregullime mënyre Aeroplan</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mënyra Aeroplan</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Pajisjet e Mia</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Rregullime Bluetooth-i</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Çaktivizuar</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation>Nëse doni të lidheni me një Bluetooth, së pari çaktivizoni [Mënyrën Aeroplan](#)</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Çaktivizoje</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Rregullime Bluetooth-i</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 e lidhur</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Po lidhet…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Çaktivizuar</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>E lidhur me %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Ndriçim</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Rregullime ekrani</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Rregullime ekrani</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Ndriçim</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Die</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Hën</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Mër</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Enj</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pre</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sht</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Shtoni skemë tastiere</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datë dhe kohë</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>orë 12-orëshe</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>orë 24-orëshe</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Rregullime kohe</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Hape kalendarin</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>E hënë</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>E martë</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>E mërkurë</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>E enjte</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>E premte</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>E shtunë</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>E diel</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>e hënë</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>e martë</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>e mërkurë</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>e enjte</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>e premte</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>e shtunë</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>e diel</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Pajisje të Tjera</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Mënyrë DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Rregullime mënyre DND</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Çaktivizoje</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Mënyra DND e aktivizuar</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Mënyra DND e çaktivizuar</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Mënyrë DND</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Rehati Sysh</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Rehati sysh e aktivizuar</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Rehati sysh e çaktivizuar</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Rregullime ekrani</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Rehati sysh</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Temë</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>E çelët</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>E errët</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Çaktivizoni rehati sysh</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Aktivizoni rehati sysh</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Rregullime Ekrani</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Temë: E çelët</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Temë: E errët</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Temë: Auto</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Efekt pamor</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>E çelët</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>E errët</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Temë</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>S’ka mesazhe</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Rregullime njoftimesh</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Njoftim</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Çaktivizo mënyrën DND</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Aktivizo mënyrën DND</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Njoftim</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Balanced</source>
        <translation>E baraspeshuar</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Kursyes Energjie</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Energji</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Rregullime energjie</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, edhe %2m</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, edhe %2h e %3m</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Po ngarkohet %1, edhe %2m, deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Po ngarkohet %1, edhe %2h e %3m, deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacitet %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Po ngarkohet %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacitet %1…</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacitet %1, plotësisht e ngarkuar</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Kapacitet %1, s’po ngarkohet</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Bateri</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Ngarkim, po llogaritet kohë e përafërt ngarkimi</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Po llogaritet kohë përdorimi e mbetur</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>Edhe %1m</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>Edhe %1h %2m</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>S’po ngarkohet</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Plotësisht e ngarkuar</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Po ngarkohet, %1m, deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Po ngarkohet, %1h e %2m, deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Kapacitet %1, edhe %2h</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>Edhe %1h</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Po ngarkohet %1, edhe %2h, deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Po ngarkohet, %1h, deri sa të jetë plot</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Rregullime energjie</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Muzikë</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>E panjohur</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Fike</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Plogështoje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kyçe</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Rregullime energjie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Përditësoje dhe Fiku</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Përditësoje dhe Rinisu</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Fiku</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Ndërroni përdorues</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Sot</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Hënor</translation>
    </message>
    <message>
        <source>y</source>
        <translation>v</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>E hënë</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>E martë</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>E mërkurë</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>E enjte</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>E premte</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>E shtunë</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>E diel</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Jan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Shk</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Pri</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Maj</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Qer</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Kor</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Gus</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Sht</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Tet</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nën</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dhj</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Hape kalendarin</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>e hënë</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>e martë</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>e mërkurë</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>e enjte</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>e premte</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>e shtunë</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>e diel</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volum</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Rregullime zëri</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zë</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Ktheji zërin</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Hiqi zërin</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Rregullime zëri</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>S’ka pajisje output-i</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volum %1</translation>
    </message>
</context>
</TS>